From 9263f07d7017a34edbea07a8f39c8936b4690f66 Mon Sep 17 00:00:00 2001
From: Justin Clarke Casey
Date: Wed, 21 May 2008 23:52:02 +0000
Subject: * Send VersionInfo string instead of the hardcoded Scene string to
the "About Second Life" box * This is the same string as printed out on the
opensim region console at startup, so it should now include the svn revision
number (if available) * This dialog box takes an awful long time to come up
on my local system - no idea why that is. However, that also seems to have
been the case before this revision.
---
OpenSim/Region/Application/OpenSimMain.cs | 15 ++++++---------
OpenSim/Region/Application/VersionInfo.cs | 3 ++-
2 files changed, 8 insertions(+), 10 deletions(-)
(limited to 'OpenSim/Region/Application')
diff --git a/OpenSim/Region/Application/VersionInfo.cs b/OpenSim/Region/Application/VersionInfo.cs
index f9146c5..430c413 100644
--- a/OpenSim/Region/Application/VersionInfo.cs
+++ b/OpenSim/Region/Application/VersionInfo.cs
@@ -28,9 +28,10 @@
namespace OpenSim
{
///
+ /// Exists purely to hold version information.
///
public class VersionInfo
{
- public static string Version = "trunk (0.5.6 and additional code)";
+ public static string Version = "trunk (post 0.5.6)";
}
}
diff --git a/OpenSim/Region/Application/OpenSimMain.cs b/OpenSim/Region/Application/OpenSimMain.cs
index 7d09c07..a48b580 100644
--- a/OpenSim/Region/Application/OpenSimMain.cs
+++ b/OpenSim/Region/Application/OpenSimMain.cs
@@ -346,10 +346,10 @@ namespace OpenSim
}
///
/// Print the version information available to the library. This include a subversion number if the root
/// .svn/entries file is present.
///
- protected void printAvailableVersionInformation()
+ protected void updateAvailableVersionInformation()
{
// Set BuildVersion String for Show version command
string svnFileName = "../.svn/entries";
@@ -379,11 +379,7 @@ namespace OpenSim
if (!string.IsNullOrEmpty(buildVersion))
{
- m_log.Info("[STARTUP]: OpenSim version: " + VersionInfo.Version + ", SVN build r" + buildVersion + "\n");
- }
- else
- {
- m_log.Info("[STARTUP]: OpenSim version: " + VersionInfo.Version + "\n");
+ VersionInfo.Version += ", SVN build r" + buildVersion;
}
}
@@ -392,7 +388,8 @@ namespace OpenSim
///
protected void InternalStartUp()
{
- printAvailableVersionInformation();
+ updateAvailableVersionInformation();
+ m_log.Info("[STARTUP]: OpenSim version: " + VersionInfo.Version + "\n");
m_stats = StatsManager.StartCollectingSimExtraStats();
@@ -346,10 +346,10 @@ namespace OpenSim
}
///
- /// Print the version information available to the library. This include a subversion number if the root
- /// .svn/entries file is present.
+ /// Update the version string with extra information if it's available.
+ /// This currently means adding a subversion number if the root .svn/entries file is present.
///
--
cgit v1.1